====================================
Adding support for a new file format
====================================

.. options - direct IO or RawIO

.. mention possibility of connecting directly to a DB

.. provide test files

.. pull request - link to `contributing`

.. pull in content from io_developers_guide
